@@ -14,9 +14,8 @@ sub new_with_data {
 }
 
 sub write_and_compare {
-  my ($t, $name, $truthname) = @_;
+  my ($t, $name, $truthname, $suffix) = @_;
   
-  my $suffix = GD::Image->can('gif') ? 'gif' : 'png';
   my $outfile = "$name.$suffix";
   my $method = "write_$suffix";
   $t->$method($outfile);
@@ -31,13 +30,4 @@ sub files_identical {
   return $data_one eq $data_two;
 }
 
-sub report_result {
-  my $bad = !shift;
-  use vars qw($TEST_NUM);
-  $TEST_NUM++;
-  print "not "x$bad, "ok $TEST_NUM\n";
-  
-  print $_[0] if ($bad and $ENV{TEST_VERBOSE});
-}
-
 1;
